==> libvoikko_3.5.orig.tar.gz: libvoikko-3.5/java/src/main/java/org/puimula/libvoikko/Token.java <==
/* The contents of this file are subject to the Mozilla Public License Version 
 * 1.1 (the "License"); you may not use this file except in compliance with 
 * the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 * 
 * The Original Code is Libvoikko: Library of natural language processing tools.
 * The Initial Developer of the Original Code is Harri Pitkänen <hatapitk@iki.fi>.
 * Portions created by the Initial Developer are Copyright (C) 2010
 * the Initial Developer. All Rights Reserved.
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *********************************************************************************/

package org.puimula.libvoikko;

/**
 * Represents a token in tokenized natural language text.
 */
public class Token {

    private final TokenType type;
    private final String text;
    
    public Token(TokenType type, String text) {
        this.type = type;
        this.text = text;
    }

    /**
     * @return type of the token
     */
    public TokenType getType() {
        return type;
    }

    /**
     * @return token as text
     */
    public String getText() {
        return text;
    }
    
}

==> libvoikko_4.3.orig.tar.gz: libvoikko-4.3/java/src/main/java/org/puimula/libvoikko/Token.java <==
/* The contents of this file are subject to the Mozilla Public License Version 
 * 1.1 (the "License"); you may not use this file except in compliance with 
 * the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 * 
 * The Original Code is Libvoikko: Library of natural language processing tools.
 * The Initial Developer of the Original Code is Harri Pitkänen <hatapitk@iki.fi>.
 * Portions created by the Initial Developer are Copyright (C) 2010
 * the Initial Developer. All Rights Reserved.
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *********************************************************************************/

package org.puimula.libvoikko;

/**
 * Represents a token in tokenized natural language text.
 */
public class Token {

    private final TokenType type;
    private final String text;
    private final int startOffset;
    
    public Token(TokenType type, String text, int startOffset) {
        this.type = type;
        this.text = text;
        this.startOffset = startOffset;
    }

    /**
     * @return type of the token
     */
    public TokenType getType() {
        return type;
    }

    /**
     * @return token as text
     */
    public String getText() {
        return text;
    }

    /**
     * @since 4.2
     * @return start offset of token
     */
    public int getStartOffset() {
        return startOffset;
    }

    /**
     * @since 4.2
     * @return end offset of token
     */
    public int getEndOffset() {
        return startOffset + text.length();
    }
    
}
